pub enum JobState {
Canceled,
Aborted,
Completed,
Pending,
Processing,
}Variants
Canceled
End state - indicates that the job was canceled either by the remote client application (thru the eSCL interface) or by the user interacting with the scanner directly. Check JobStateReasons for more details.
Aborted
End state - either an internal device error, or a communication error or a security error
Completed
Job is finished successfully
Pending
The job was initiated, and the scanner is preparing the scan engine
Processing
The scanner is processing the job and is transmitting the scan data